@@ -5,7 +5,7 @@ use Mojo::Util ('md5_bytes');
 use Mojo::Base 'Mojo::Transaction::WebSocket';
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 use constant DEBUG => &Mojo::Transaction::WebSocket::DEBUG;
@@ -234,11 +234,11 @@ L<http://github.com/dionys/mojox-transaction-websocket76/issues>
 
 =head1 AUTHOR
 
-Denis Ibaev, C<dionys@cpan.org>.
+Denis Ibaev, C<dionys@cpan.org> for Setup.ru.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012, Denis Ibaev.
+Copyright (C) 2012-2013, Denis Ibaev.
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
